#!/bin/sh
scriptdir=`dirname $0` ; cd ${scriptdir} ; scriptdir=`pwd` ; cd - > /dev/null

livedefault=false
partedbin=`sudo which parted`
bootlabel=BOOT
bootuuid=1234-5678

mountimg() {
  echo "Extracting ip/$1.img.gz"
  gzip -cd ${workdir}/iso/ip/$1.img.gz > ${workdir}/$1.img

  if [ $1 = gaius ]; then
    ofs=0
    sze=0
    while read n b e s t f z ; do
      ofs=`echo $b | tr -d B`
      sze=`echo $s | tr -d B`
      #echo ofs: $ofs sze: $sze
    done <<< $(LANG=C $partedbin ${workdir}/$1.img unit b print 2>/dev/null | grep -m1 fat)

    echo ofs: $ofs sze: $sze

    dd if=/dev/zero of=${workdir}/$1.img count=0 bs=1048576 seek=1024

#rm 1
#mkpart primary fat32 ${ofs}B 1073741823B
#Ignore
#toggle 1 boot

    LANG=C $partedbin ${workdir}/$1.img <<EOF
unit b
print
resize 1 ${ofs}B 1073741823B
resizepart 1 1073741823B
quit
EOF

    LOOPDEV=`sudo losetup --find --show -o ${ofs} --sizelimit 1072693248 ${workdir}/$1.img`

    lbl=`sudo fatlabel $LOOPDEV | tail -1`
    uid=`sudo blkid $LOOPDEV -o export | grep -E '^UUID=' | cut -d '=' -f 2 | tr -d -`

    bootlabel=$lbl
    bootuuid=`sudo blkid $LOOPDEV -o export | grep -E '^UUID=' | cut -d '=' -f 2`

    echo ID: $uid label: $lbl

    sudo mkfs.vfat -F 32 -h 2048 -i $uid -n $lbl $LOOPDEV
    sudo fatlabel $LOOPDEV
    sudo losetup -d $LOOPDEV
  fi

  ofs=0
  sze=0
  LANG=C $partedbin ${workdir}/$1.img unit b print
  LANG=C $partedbin ${workdir}/$1.img unit b print 2>/dev/null | grep -m1 fat | while read n b e s t f z ; do
    ofs=`echo $b | tr -d B`
    sze=`echo $s | tr -d B`

    #echo mount -o loop,ro,offset=$ofs,sizelimit=$sze ${workdir}/$1.img ${workdir}/mount
    sudo mount -o loop,offset=$ofs,sizelimit=$sze ${workdir}/$1.img ${workdir}/mount
  done
}

cpdir(){
  if [ -e $1 ]; then
    cp -ap --no-preserve=ownership $1 $2
  fi
}

cpfile(){
  if [ -e $1 ]; then
    cp -p --no-preserve=ownership $1 $2
  fi
}

isofile=HPIP.iso
for f in `ls -tr HPIP*.iso IP*.iso 2>/dev/null` ; do
  isofile=$f
done

if [ ! -e ${isofile} ]; then
  isofile=HPIP164B.2017_0201.3.iso
  # Gen8
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v108035/HPIP163.2016_0720.i192.227.iso
  wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v125952/HPIP164B.2017_0201.3.iso
  # Gen9
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v109733/HPIP250.2016_1015.169.iso
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v128888/HPIP261.2017_0518.11.iso
  # Gen10
  #wget -N https://downloads.hpe.com/pub/softlib2/software1/cd/p1450150448/v105991/IP300.2017_0606.382.iso
fi

[ ! -e ${isofile} ] && exit 1

workdir=${isofile/.iso/}

if [ ! -e ${workdir} ]; then
  bash hpip-extract.sh
fi

partedbin=`sudo which parted`

echo ""
echo Using ${workdir}


liveiso=Debian.iso
for f in `ls -tr *bian*.iso *buntu*.iso *admincd*.iso *arch*.iso *makeiso*.iso *CentOS*.iso *kali*.iso *Core*.iso *nano*.iso *slack*.iso *slax*.iso *tahr*.iso *live*.iso *emergency*.iso *grml*.iso *magic*.iso *repair*.iso *rescue*.iso *7pe*.iso *win*.iso *win*.ISO *7PE*.iso *Win*.iso *Win*.ISO *ccmulti*.iso 2>/dev/null` ; do
  liveiso=$f
done

if [ ! -e ${liveiso} ]; then
  liveiso=gparted-live-0.29.0-1-amd64.iso
  wget -N https://downloads.sourceforge.net/project/gparted/gparted-live-stable/0.29.0-1/gparted-live-0.29.0-1-amd64.iso
fi

[ ! -e ${liveiso} ] && exit 1

livedir=${liveiso}
livedir=${livedir/.iso/}
livedir=${livedir/.ISO/}
liveShort=`echo ${livedir} | sed s/'-x86_64'/''/g | sed s/'[-_.][0-9_.-]*[-_]'/'-'/g | sed s/'[-_][0-9.-]*$'/''/g | sed s/'-64bit'/''/g | sed s/'-amd64+mac'/''/g | sed s/'-amd64'/''/g | sed s/'-x64'/''/g | sed s/'-x86'/''/g | sed s/'-uefi'/''/g | tr _ -`
liveName=`echo ${liveShort} | tr - ' '`
liveShort=`echo ${liveShort} | tr ' ' -`

liveLabel=`isoinfo -d -i ${liveiso} | grep -E '^Volume id:' | cut -d : -f 2- | tr -d ' '`

echo Using ${liveName} in ${livedir}
echo ISO label: ${liveLabel}

sudo mount -o loop,ro ${liveiso} ${workdir}/mount

mkdir -p ${workdir}/liveiso
cp -apP --no-preserve=ownership ${workdir}/mount/. ${workdir}/liveiso/
sudo chmod -R ugo+rw ${workdir}/liveiso/
sudo umount ${workdir}/mount

cd ${workdir}/liveiso/

liveMode=unknown
liveFDir=.
liveFS=filesystem.squashfs

for f in `ls *.squashfs 2>/dev/null` ; do
  liveMode=live
  liveFDir=`dirname $f`
  liveFS=`basename $f`
  mkdir -p ${liveMode}
done

for f in `ls puppy_*.sfs 2>/dev/null` ; do
  liveMode=puppy
  liveFDir=.
  liveFS=$f
  mkdir -p ${liveMode}
done

for f in `ls arch/*/*.sfs 2>/dev/null` ; do
  liveMode=arch
  liveFDir=`dirname $f`
  liveFS=`basename $f`
done

for f in `ls live/*/*.squashfs 2>/dev/null` ; do
  liveMode=live
  liveFDir=`dirname $f`
  liveFS=`basename $f`
done

for f in `ls pmagic/*/*.SQFS 2>/dev/null` ; do
  liveMode=pmagic
  liveFDir=`dirname $f`
  liveFS=`basename $f`
done

if [ -e casper/filesystem.squashfs ]; then
  liveMode=casper
  liveFDir=${liveMode}
  liveFS=filesystem.squashfs

elif [ -e live/filesystem.squashfs ]; then
  liveMode=live
  liveFDir=${liveMode}
  liveFS=filesystem.squashfs

elif [ -e LiveOS/squashfs.img ]; then
  liveMode=LiveOS
  liveFDir=${liveMode}
  liveFS=squashfs.img

elif [ -e images/install.img ]; then
  liveMode=images
  liveFDir=${liveMode}
  liveFS=install.img

elif [ -e pmagic/pmodules ]; then
  liveMode=pmagic

elif [ -e sysrcd.dat ]; then
  liveMode=sysrcd
  liveFDir=.
  liveFS=sysrcd.dat
  mkdir -p ${liveMode}

elif [ -e syslinux/alt0 -a -e rescue ]; then
  liveMode=alt0
  liveFDir=.
  liveFS=rescue
  mkdir -p ${liveMode}

elif [ -e livecd.loop ]; then
  liveMode=livecd
  liveFDir=.
  liveFS=livecd.loop
  mkdir -p ${liveMode}

elif [ -e cde ]; then
  liveMode=ucore
  mkdir -p ${liveMode}

elif [ -e KNOPPIX/KNOPPIX ]; then
  liveMode=KNOPPIX
  liveFDir=KNOPPIX
  liveFS=KNOPPIX

elif [ -e sources/boot.wim ]; then
  liveMode=winpe
  liveFDir=sources
  liveFS=boot.wim

elif [ -e sources/BOOT.WIM ]; then
  liveMode=winpe
  liveFDir=sources
  liveFS=BOOT.WIM

fi

if [ X${liveMode} = Xunknown ]; then
  echo "Unknown live ISO format"
  exit 1
fi

if [ -e ${liveFDir}/${liveFS} ]; then
  echo "Using fs ${liveFDir}/${liveFS}"
fi

if [ $liveMode = winpe ]; then
  liveInit=boot.sdi

  if [ -e boot/boot.sdi ]; then
    liveInit=boot/boot.sdi
  elif [ -e BOOT/BOOT.SDI ]; then
    liveInit=BOOT/BOOT.SDI
  fi

  liveKern=ntldr

  if [ -e bootmgr ]; then
    liveKern=bootmgr
  elif [ -e BOOTMGR ]; then
    liveKern=BOOTMGR
  fi

else
  liveIDir=${liveMode}
  liveInit=initrd

  for f in `ls arch/boot/*/arch*.i* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls syslinux/*/full*.?z 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls syslinux/*/initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls isolinux/gentoo.i* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls isolinux/initram* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls isolinux/initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls boot/*/minirt* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls boot/*/initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls boot/core*.?z 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls boot/initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  for f in `ls ./initrd* 2>/dev/null` ; do
    liveIDir=`dirname $f`
    liveInit=`basename $f`
  done

  if [ -e ${liveMode}/initrd.lz ]; then
    liveIDir=${liveMode}
    liveInit=initrd.lz
  elif [ -e ${liveMode}/initrd.gz ]; then
    liveIDir=${liveMode}
    liveInit=initrd.gz
  elif [ -e ${liveMode}/initrd.img ]; then
    liveIDir=${liveMode}
    liveInit=initrd.img
  elif [ -e ${liveMode}/minirt.gz ]; then
    liveIDir=${liveMode}
    liveInit=minirt.gz
  elif [ -e ${liveMode}/full.cz ]; then
    liveIDir=${liveMode}
    liveInit=full.cz
  fi

  if [ ${liveIDir} != ${liveMode} ]; then
    cp -p --no-preserve=ownership ${liveIDir}/${liveInit} ${liveMode}/
  fi

  if [ ! -e ${liveMode}/${liveInit} ]; then
    echo "Unknown live ISO format, initrd not found"
    exit 1
  fi

  echo Using init ${liveIDir}/${liveInit}

  liveKDir=${liveMode}
  liveKern=vmlinux

  for f in `ls arch/boot/*/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls syslinux/*/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls isolinux/rescue32* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls isolinux/rescue64* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls isolinux/gentoo 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls isolinux/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/*/linux 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/*/gentoo 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/*/bzImage* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/*/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls boot/vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  for f in `ls ./vmlinu* 2>/dev/null` ; do
    liveKDir=`dirname $f`
    liveKern=`basename $f`
  done

  if [ -e ${liveMode}/vmlinuz ]; then
    liveKDir=${liveMode}
    liveKern=vmlinuz
  elif [ -e ${liveMode}/vmlinuz.efi ]; then
    liveKDir=${liveMode}
    liveKern=vmlinuz.efi
  elif [ -e ${liveMode}/bzImage64 ]; then
    liveKDir=${liveMode}
    liveKern=bzImage64
  elif [ -e ${liveMode}/bzImage ]; then
    liveKDir=${liveMode}
    liveKern=bzImage
  elif [ -e ${liveMode}/linux ]; then
    liveKDir=${liveMode}
    liveKern=linux
  fi

  if [ ${liveKDir} != ${liveMode} ]; then
    cp -p --no-preserve=ownership ${liveKDir}/${liveKern} ${liveMode}/
  fi

  if [ ! -e ${liveMode}/${liveKern} ]; then
    echo "Unknown live ISO format, kernel not found"
    exit 1
  fi

  echo Using kernel ${liveKDir}/${liveKern}
fi

cd ${scriptdir}

mountimg gaius

sudo cp -ap --no-preserve=ownership ${workdir}/gaius/. ${workdir}/mount/

cd ${scriptdir}/${workdir}/mount

mkdir -p ${scriptdir}/${workdir}/gaius-add/boot/grub
cp -p ./boot/grub/grub.cfg ${scriptdir}/${workdir}/gaius-add/boot/grub/

cd ${scriptdir}/${workdir}/gaius-add

if [ ! -e ${scriptdir}/grub.cfg-${liveMode} ]; then
  cp -p --no-preserve=ownership ${scriptdir}/grub.cfg-live ./boot/grub/grub.cfg
  sed -i "s|/live/vmlinuz|/${liveMode}/vmlinuz|g" ./boot/grub/grub.cfg
  sed -i "s|/live/initrd|/${liveMode}/initrd|g" ./boot/grub/grub.cfg
else
  cp -p --no-preserve=ownership ${scriptdir}/grub.cfg-${liveMode} ./boot/grub/grub.cfg
fi

cd ${scriptdir}/${workdir}/mount

livesrc=${scriptdir}/${workdir}/liveiso

if [ $liveMode = winpe ]; then
  #sudo rm boot/initrd.img
  #sudo rm boot/vmlinuz
  #sudo rm -rf hotfixes/
  #sudo rm system/squashfs.img

  sudo rm sources/boot.wim

  cd ${scriptdir}/${workdir}/gaius-add

  mkdir -p ./sources


  cpdir ${livesrc}/Programs ./

  cp -p --no-preserve=ownership ${livesrc}/sources/boot.wim ./sources/

  cpfile ${livesrc}/CdUsb.* ./
  cpfile ${livesrc}/pecmd*.ini ./
  cpfile ${livesrc}/Win*PE*.cd ./
  cpfile ${livesrc}/Win*SE*.cd ./

  sed -i "s|Windows PE|${liveName}|g" ./boot/grub/grub.cfg

else
  cd ${livesrc}

  lxcmdline="boot=${liveMode}"

  tempLdr=none
  tempDir=boot
  tempCfg=grub.cfg

  if [ -e boot/grub/loopback.cfg ]; then
    tempLdr=grub
    tempDir=boot/grub
    tempCfg=boot/grub/loopback.cfg
  fi
  if [ -e boot/grub/grub.cfg     ]; then
    tempLdr=grub
    tempDir=boot/grub
    tempCfg=boot/grub/grub.cfg
  fi

  if [ $tempLdr = grub -a -e ${tempCfg} ]; then
    if [ ${liveKDir} != ${liveMode} ]; then
      lxcmdtemp=`cat ${tempCfg} | sed s/'^[ \t]*linux'/'linux'/g | grep -m1 -E 'linux.*'/${liveKDir}/${liveKern} | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
    else
      lxcmdtemp=`cat ${tempCfg} | sed s/'^[ \t]*linux'/'linux'/g | grep -m1 -E 'linux.*'/${liveKDir}/${liveKern}`
    fi

    if echo X${lxcmdtemp} | grep -q -m1 -E 'linux.*'/${liveMode}/${liveKern} ; then
      liveLdr=${tempLdr}
      liveCfg=${tempCfg}
      lxcmdline=$lxcmdtemp
    fi
  fi

  tempLdr=none
  tempCfg=isolinux.cfg

  if [ -e boot/syslinux/syslinux.cfg ]; then
    tempLdr=syslinux
    tempDir=boot/syslinux
    tempCfg=boot/syslinux/syslinux.cfg
  fi
  if [ -e boot/isolinux/isolinux.cfg ]; then
    tempLdr=syslinux
    tempDir=boot/isolinux
    tempCfg=boot/isolinux/isolinux.cfg
  fi
  if [ -e boot/isolinux/default.cfg ]; then
    tempLdr=syslinux
    tempDir=boot/isolinux
    tempCfg=boot/isolinux/default.cfg
  fi
  if [ -e syslinux/isolinux.cfg ]; then
    tempLdr=syslinux
    tempDir=syslinux
    tempCfg=syslinux/isolinux.cfg
  fi
  if [ -e isolinux/isolinux.cfg ]; then
    tempLdr=syslinux
    tempDir=isolinux
    tempCfg=isolinux/isolinux.cfg
  fi
  if [ -e isolinux/txt.cfg ]; then
    tempLdr=syslinux
    tempDir=isolinux
    tempCfg=isolinux/txt.cfg
  fi
  if [ -e ./isolinux.cfg ]; then
    tempLdr=syslinux
    tempDir=.
    tempCfg=./isolinux.cfg
  fi
  if [ -e arch/boot/syslinux/syslinux.cfg ]; then
    tempLdr=syslinux
    tempDir=arch
    tempCfg=arch/boot/syslinux/syslinux.cfg
  fi
  if [ -e arch/boot/syslinux/archiso_sys.cfg ]; then
    tempLdr=syslinux
    tempDir=arch
    tempCfg=arch/boot/syslinux/archiso_sys.cfg
  fi
  if [ -e arch/boot/syslinux/archiso_sys64.cfg ]; then
    tempLdr=syslinux
    tempDir=arch
    tempCfg=arch/boot/syslinux/archiso_sys64.cfg
  fi

  if [ $tempLdr = syslinux -a -e ${tempCfg} ]; then
    trekDir=`echo ${liveKDir}/ | sed "s|^${tempDir}/||g"`
    trelDir=`echo ${liveIDir}/ | sed "s|^${tempDir}/||g"`
    tGotCmd=false

    if [ ${liveKDir} != ${liveMode} ]; then
      lxcmdtemp=`cat ${tempCfg} | grep -v '#append' | grep -m1 -E 'append.*initrd=.*'${trelDir}${liveInit} | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
    else
      lxcmdtemp=`cat ${tempCfg} | grep -v '#append' | grep -m1 -E 'append.*initrd=.*'${trelDir}${liveInit}`
    fi

    if echo X${lxcmdtemp} | grep -q -m1 -E 'append.*initrd=.*'${trelDir}${liveInit} ; then
      tGotCmd=true
      liveLdr=${tempLdr}
      liveCfg=${tempCfg}
      lxcmdline='linux	'/${liveMode}/${liveKern}'  '`echo $lxcmdtemp | sed s/'\\\\x20'//g | sed s/'.*append'/''/g | sed 's|initrd='/${liveIDir}/${liveInit}'||g' | sed 's|initrd='${trelDir}${liveInit}'||g'`
    fi

    if [ $tGotCmd = false ] ; then
      if [ ${liveKDir} != ${liveMode} ]; then
        lxcmdtemp=`cat ${tempCfg} | grep -m1 -A1 -E 'INITRD.*'${trelDir}${liveInit} | grep -v '#APPEND' | grep APPEND | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
      else
        lxcmdtemp=`cat ${tempCfg} | grep -m1 -A1 -E 'INITRD.*'${trelDir}${liveInit} | grep -v '#APPEND' | grep APPEND`
      fi

      if echo X${lxcmdtemp} | grep -q APPEND ; then
        tGotCmd=true
        liveLdr=${tempLdr}
        liveCfg=${tempCfg}
        lxcmdline='linux	'/${liveMode}/${liveKern}'  '`echo $lxcmdtemp | sed s/'\\\\x20'//g | sed s/'.*APPEND'/''/g`
      fi
    fi

    if [ $tGotCmd = false ] ; then
      if [ ${liveKDir} != ${liveMode} ]; then
        lxcmdtemp=`cat ${tempCfg} | grep -m1 -A1 -E 'initrd.*'${trelDir}${liveInit} | grep -v '#append' | grep append | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
      else
        lxcmdtemp=`cat ${tempCfg} | grep -m1 -A1 -E 'initrd.*'${trelDir}${liveInit} | grep -v '#append' | grep append`
      fi

      if echo X${lxcmdtemp} | grep -q append ; then
        tGotCmd=true
        liveLdr=${tempLdr}
        liveCfg=${tempCfg}
        lxcmdline='linux	'/${liveMode}/${liveKern}'  '`echo $lxcmdtemp | sed s/'\\\\x20'//g | sed s/'.*append'/''/g`
      fi
    fi

    if [ $tGotCmd = false ] ; then
      if [ ${liveKDir} != ${liveMode} ]; then
        lxcmdtemp=`cat ${tempCfg} | grep -A2 -E 'LINUX.*'${trekDir}${liveKern} | grep -v '#APPEND' | grep -m1 -B2 APPEND | grep APPEND | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
      else
        lxcmdtemp=`cat ${tempCfg} | grep -A2 -E 'LINUX.*'${trekDir}${liveKern} | grep -v '#APPEND' | grep -m1 -B2 APPEND | grep APPEND`
      fi

      if echo X${lxcmdtemp} | grep -q APPEND ; then
        tGotCmd=true
        liveLdr=${tempLdr}
        liveCfg=${tempCfg}
        lxcmdline='linux	'/${liveMode}/${liveKern}'  '`echo $lxcmdtemp | sed s/'\\\\x20'//g | sed s/'.*APPEND'/''/g`
      fi
    fi

    if [ $tGotCmd = false ] ; then
      if [ ${liveKDir} != ${liveMode} ]; then
        lxcmdtemp=`cat ${tempCfg} | grep -A2 -E 'linux.*'${trekDir}${liveKern} | grep -v '#append' | grep -m1 -B2 append | grep append | sed "s|${liveKDir}/${liveKern}|${liveMode}/${liveKern}|g"`
      else
        lxcmdtemp=`cat ${tempCfg} | grep -A2 -E 'linux.*'${trekDir}${liveKern} | grep -v '#append' | grep -m1 -B2 append | grep append`
      fi

      if echo X${lxcmdtemp} | grep -q append ; then
        tGotCmd=true
        liveLdr=${tempLdr}
        liveCfg=${tempCfg}
        lxcmdline='linux	'/${liveMode}/${liveKern}'  '`echo $lxcmdtemp | sed s/'\\\\x20'//g | sed s/'.*append'/''/g`
      fi
    fi

    if [ $tGotCmd = true -a $liveMode = puppy ]; then
      if ! echo $lxcmdline | grep -q ' pmedia=' ; then
        lxcmdline="${lxcmdline} pmedia=cd"
      fi

      lxcmdline=${lxcmdline/pfix=ram,/pfix=}
      lxcmdline=${lxcmdline/pfix=ram/}
    fi
  fi


  cd ${scriptdir}/${workdir}/gaius-add

  sed -i 's|'${liveMode}/initrd.lz'|'${liveMode}/${liveInit}'|g' ./boot/grub/grub.cfg

  cpdir ${livesrc}/.disk ./
  cpdir ${livesrc}/conf ./
  cpdir ${livesrc}/dists ./
  cpdir ${livesrc}/install ./
  cpdir ${livesrc}/pool ./
  cpdir ${livesrc}/preseed ./

  cpdir ${livesrc}/cde ./

  cpdir ${livesrc}/Packages ./

  cp -ap --no-preserve=ownership ${livesrc}/${liveMode} ./

  echo $lxcmdline
  if echo $lxcmdline | grep -q ${liveKern} ; then
    lxcmdtoram=`echo ${lxcmdline} | sed s/'boot='${liveMode}' '/'boot='${liveMode}' toram '/g | sed s/'archisobasedir='${liveMode}' '/'archisobasedir='${liveMode}' copytoram=y '/g`

    echo $lxcmdtoram
    echo got cmdline from ${liveCfg}

    #sed -i 's|linux.*'/${liveMode}/vmlinuz'.*|'${lxcmdline}'|g' ./boot/grub/grub.cfg
    sed -i "s|linux.*/${liveMode}/vmlinuz.*toram.*|xXlinux-cmdline-toram-hereXx|g" ./boot/grub/grub.cfg
    sed -i "s|linux.*/${liveMode}/vmlinuz.*|${lxcmdline}|g" ./boot/grub/grub.cfg
    sed -i "s|xXlinux-cmdline-toram-hereXx|${lxcmdtoram}|g" ./boot/grub/grub.cfg

    sed -i "s/automatic=method:cdrom /automatic=method:disk,uuid:${bootuuid} /g" ./boot/grub/grub.cfg
    if [ X${liveLabel} != X ]; then
      sed -i "s|archisolabel=${liveLabel}|archisolabel=${bootlabel}|g" ./boot/grub/grub.cfg
      sed -i "s|inst.stage2=hd:LABEL=${liveLabel}|inst.stage2=hd:LABEL=${bootlabel}|g" ./boot/grub/grub.cfg
    else
      sed -i "s|archisolabel=ARCH_[0-9]*|archisolabel=${bootlabel}|g" ./boot/grub/grub.cfg
    fi
  else
    if [ ! -e ./${liveMode}/vmlinuz ]; then
      #cp -p ./${liveKDir}/${liveKern} ./${liveMode}/vmlinuz
      sed -i "s|/${liveMode}/vmlinuz|/${liveMode}/${liveKern}|g" ./boot/grub/grub.cfg
    fi
  fi

  sed -i "s|Debian-XFCE|${liveName}|g" ./boot/grub/grub.cfg
  sed -i "s|Xubuntu|${liveName}|g" ./boot/grub/grub.cfg

  if [ $livedefault = true ]; then
    sed -i "s|set default=0|set default=2|g" ./boot/grub/grub.cfg
  fi

  cpfile ${livesrc}/${liveFS} ./
  cpfile ${livesrc}/zdrv_*.sfs ./

  cpfile ${livesrc}/md5sum.txt ./
  cpfile ${livesrc}/README.diskdefines ./
  cpfile ${livesrc}/ubuntu ./

  cpfile ${livesrc}/*-Live-* ./
  cpfile ${livesrc}/GPL ./
  cpfile ${livesrc}/livecd ./
fi

cd ${scriptdir}

liveSize=`du -d0 -B1 ${workdir}/gaius-add/ | cut -f 1`

cd ${workdir}/mount/

freeSize=`df -B1 --output=avail . | tail -1`
freeSize=`expr ${freeSize} - 5000000`

  echo ""
  df -B1 .
  #echo "${freeSize} free"
  echo ""

  if [ ${liveSize} -gt ${freeSize} -a $liveMode != winpe ]; then
  #if [ -e ${livesrc}/${liveFDir}/${liveFS} ]; then
  #  if [ `stat -c %s ${livesrc}/${liveFDir}/${liveFS}` -gt 246000000 ]; then
      echo "Deleting PE"
      sudo rm -f bootmgr
      sudo rm -f bootmgr.efi

      sudo rm -f boot/BCD
      sudo rm -f boot/bootfix.bin
      sudo rm -f boot/boot.sdi

      sudo rm -rf EFI/Microsoft/

      sudo rm -rf sources/
      sudo rm -rf win/
      sudo rm -rf winpe/

      freeSize=`df -B1 --output=avail . | tail -1`
      freeSize=`expr ${freeSize} - 5000000`

      df -B1 .
      #echo "${freeSize} free"
      echo ""
  #  fi
  fi

  if [ ${liveSize} -gt ${freeSize} ]; then
  #if [ -e ${livesrc}/${liveFDir}/${liveFS} ]; then
    #if [ `stat -c %s ${livesrc}/${liveFDir}/${liveFS}` -gt 580000000 ]; then
      livedefault=true
      echo "Deleting IP"
      sudo rm boot/initrd.img
      sudo rm boot/vmlinuz
      sudo rm -rf hotfixes/
      sudo rm system/squashfs.img
      df -B1 .
      echo ""
    #fi
  fi

cd ${scriptdir}

echo "Adding ${liveSize} bytes"
sudo cp -ap --no-preserve=ownership ${workdir}/gaius-add/. ${workdir}/mount/

cd ${workdir}/mount/

df -B1 .

cd ${scriptdir}

echo ""
echo "You can make your own changes in ${workdir}/mount now, if required."
echo "Press Enter when done."
read f;

sudo umount ${workdir}/mount

mkdir -p ${workdir}/combinediso
cp -apP ${workdir}/iso/. ${workdir}/combinediso/

echo "Creating ip/gaius.img.gz"
cat ${workdir}/gaius.img | gzip -c > ${workdir}/combinediso/ip/gaius.img.gz

cd ${workdir}/combinediso/ip/

sudo rm md5s.txt
sudo rm sha1sums.txt
md5sum *.img.gz > md5s.txt
shasum *.img.gz > sha1sums.txt

cd ${scriptdir}

#geteltorito ${isofile} > ${workdir}/eltorito.bin
#cp -p ${workdir}/eltorito.bin ${workdir}/combinediso/boot/grub/stage2_eltorito

IMAGE=`basename ${isofile} | cut -d _ -f 1 | cut -d . -f 1`-${liveShort}.iso
IMAGE_NAME=`basename ${isofile} | cut -d _ -f 1 | cut -d . -f 1`

cd ${workdir}/combinediso/

if false; then
  echo mkisofs -U -V "$IMAGE_NAME" \
            -J -joliet-long -r -v -T -b boot/grub/stage2_eltorito -c boot.catalog -no-emul-boot -boot-load-size 4 -boot-info-table -no-emul-boot \
            -o ../${IMAGE} .

  mkisofs -U -V "$IMAGE_NAME" \
            -J -joliet-long -r -v -T \
            -b boot/grub/stage2_eltorito -c boot.catalog -no-emul-boot -boot-load-size 4 -boot-info-table -no-emul-boot \
            -o ../${IMAGE} .
else

  LANG=C grub-mkrescue -o ../${IMAGE} . -- -volid "$IMAGE_NAME"
fi
